Index: pkg/dartino_compiler/lib/src/message_examples.dart |
diff --git a/pkg/fletchc/lib/src/message_examples.dart b/pkg/dartino_compiler/lib/src/message_examples.dart |
similarity index 96% |
rename from pkg/fletchc/lib/src/message_examples.dart |
rename to pkg/dartino_compiler/lib/src/message_examples.dart |
index 399de636452a394c1aad344f0cbc80cbe1132f9d..b8c295d03380dc265e774b0d6630009dca3bfe65 100644 |
--- a/pkg/fletchc/lib/src/message_examples.dart |
+++ b/pkg/dartino_compiler/lib/src/message_examples.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletchc.message_examples; |
+library dartino_compiler.message_examples; |
import 'messages.dart' show |
DiagnosticKind; |
@@ -71,10 +71,10 @@ List<Example> getExamples(DiagnosticKind kind) { |
case DiagnosticKind.sessionInvalidState: |
// TODO(wibling): figure out a way to test this. |
// Basically we need to have a fletch-vm that is |
// explicitly attached to via 'fletch attach' and |
// have it in a state where it has thrown an uncaught |
// exception and then call e.g. 'fletch run foo.dart'. |
return untestable; |
case DiagnosticKind.noFileTarget: |
@@ -107,7 +107,7 @@ List<Example> getExamples(DiagnosticKind kind) { |
// return <Example>[new CommandLineExample( |
// <String>['create', 'session', 'foo'], |
// <String>['x-upgrade', 'agent', |
- // 'with', 'file', 'fletch-agent_v1_platform.deb', |
+ // 'with', 'file', 'dartino-agent_v1_platform.deb', |
// 'in', 'session', 'foo' |
// ])]; |
return untestable; |
@@ -122,12 +122,12 @@ List<Example> getExamples(DiagnosticKind kind) { |
return untestable; |
case DiagnosticKind.socketAgentConnectError: |
// TODO(wibling,268): figure out how to test fletch agent failures to |
// exercise this error. |
return untestable; |
case DiagnosticKind.socketAgentReplyError: |
// TODO(wibling,268): figure out how to test fletch agent failures to |
// exercise this error. |
return untestable; |
@@ -138,7 +138,7 @@ List<Example> getExamples(DiagnosticKind kind) { |
'tcp_socket', invalidAddress])]; |
case DiagnosticKind.socketVmReplyError: |
// TODO(wibling): figure out how to simulate fletch vm failures to |
// exercise this error. |
return untestable; |
@@ -71,10 +71,10 @@ List<Example> getExamples(DiagnosticKind kind) { |
case DiagnosticKind.sessionInvalidState: |
// TODO(wibling): figure out a way to test this. |
- // Basically we need to have a fletch-vm that is |
- // explicitly attached to via 'fletch attach' and |
+ // Basically we need to have a dartino-vm that is |
+ // explicitly attached to via 'dartino attach' and |
// have it in a state where it has thrown an uncaught |
@@ -71,10 +71,10 @@ List<Example> getExamples(DiagnosticKind kind) { |
// have it in a state where it has thrown an uncaught |
- // exception and then call e.g. 'fletch run foo.dart'. |
+ // exception and then call e.g. 'dartino run foo.dart'. |
return untestable; |
case DiagnosticKind.noFileTarget: |
@@ -122,12 +122,12 @@ List<Example> getExamples(DiagnosticKind kind) { |
return untestable; |
case DiagnosticKind.socketAgentConnectError: |
- // TODO(wibling,268): figure out how to test fletch agent failures to |
+ // TODO(wibling,268): figure out how to test dartino agent failures to |
// exercise this error. |
return untestable; |
@@ -122,12 +122,12 @@ List<Example> getExamples(DiagnosticKind kind) { |
return untestable; |
case DiagnosticKind.socketAgentReplyError: |
- // TODO(wibling,268): figure out how to test fletch agent failures to |
+ // TODO(wibling,268): figure out how to test dartino agent failures to |
// exercise this error. |
return untestable; |
@@ -138,7 +138,7 @@ List<Example> getExamples(DiagnosticKind kind) { |
'tcp_socket', invalidAddress])]; |
case DiagnosticKind.socketVmReplyError: |
- // TODO(wibling): figure out how to simulate fletch vm failures to |
+ // TODO(wibling): figure out how to simulate dartino vm failures to |
// exercise this error. |
return untestable; |